@@ -17,6 +17,9 @@ class DisunityCommandContext:
         self.invoked_by = User(response['member']['user'])
         self.resolved = response['data'].get('resolved', None)
         self.acked = False
+        self.options = dict()
+        for option in response['data'].get('options', []):
+            self.options[option['name']] = option['value']
     
     async def callback(self, content: str = '', embed: Optional[Embed] = None, embeds: Optional[List[Embed]] = [], components: list = [], allowed_mentions: list = [], ephemeral: bool = False, _type: int = 4):
         """
