@@ -99,7 +99,7 @@ class DisunityServer(quart.Quart):
             component: identifiers.DisunityComponent = self._cache.components.get(str(context.custom_id).split('-')[0], None)
 
             if component is None:
-                raise errors.ComponentNotFound(f"Component: {str(context.custom_id).splut('-')[0]} was not found")
+                raise errors.ComponentNotFound(f"Component: {str(context.custom_id).split('-')[0]} was not found")
 
             if component.requires_ack:
                 resp = {"type": 6}
@@ -194,6 +194,3 @@ class DisunityServer(quart.Quart):
                 self._cache.cache_command(item)
             elif isinstance(item, identifiers.DisunityComponent):
                 self._cache.cache_component(item)
-
-    async def register_component(self, ctx, custom_id, coroutine, timeout: float = 0.0, is_single_use: bool = True, requires_ack: bool = False, requires_ephemeral: bool = False):
-        self._cache.cache_component(identifiers.DisunityComponent(ctx, custom_id, coroutine, timeout, is_single_use, requires_ack, requires_ephemeral))
